"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.errorHandlerMiddleware = void 0;
const redis_smq_common_1 = require("redis-smq-common");
const getErrorResponseParams_js_1 = require("../../../app/errors/getErrorResponseParams.js");
const ValidationError_js_1 = require("../errors/ValidationError.js");
const errorHandlerMiddleware = (ctx, next) => __awaiter(void 0, void 0, void 0, function* () {
    try {
        yield next();
    }
    catch (e) {
        console.error(e);
        if (e instanceof redis_smq_common_1.RedisSMQError) {
            const [code, message] = (0, getErrorResponseParams_js_1.getErrorResponseParams)(e);
            ctx.body = {
                error: {
                    code,
                    message,
                    details: e instanceof ValidationError_js_1.ValidationError ? e.errorObjects : {},
                },
            };
        }
        else {
            ctx.status = 500;
            ctx.body = {
                error: {
                    code: ctx.status,
                    message: 'Internal server error',
                    details: (e instanceof Error && {
                        message: e.message,
                        name: e.name,
                        stack: e.stack,
                    }) ||
                        {},
                },
            };
        }
    }
});
exports.errorHandlerMiddleware = errorHandlerMiddleware;
//# sourceMappingURL=errorHandlerMiddleware.js.map